@@ -9,21 +9,28 @@ Appends a value to a specific field, which is useful
 for adding to lists in the user.json.
 """
 
+from typing import TYPE_CHECKING, Any
+
 from mitosheet.mito_analytics import identify
 from mitosheet.user import get_user_field, set_user_field
 
+if TYPE_CHECKING:
+    from mitosheet.steps_manager import StepsManager
+else:
+    StepsManager = Any
+
 
 APPEND_USER_FIELD_EVENT = 'append_user_field_update'
 APPEND_USER_FIELD_PARAMS = ['field', 'value']
 
 
-def execute_append_user_field_update(steps_manager, field, value):
+def execute_append_user_field_update(steps_manager: StepsManager, field: str, value: Any) -> None:
     """
     The function responsible for appending value to the list
     stored at field.
     """
     field_values = get_user_field(field)
-    if field_values == None: 
+    if field_values is None: 
         field_values = []
     
     # Append the new value to the list. If the value is a list itself, we 
@@ -44,4 +51,4 @@ APPEND_USER_FIELD_UPDATE = {
     'event_type': APPEND_USER_FIELD_EVENT,
     'params': APPEND_USER_FIELD_PARAMS,
     'execute': execute_append_user_field_update
-}
\ No newline at end of file
+}
